==> jbossdm-plugin-3.8.0-sources.jar: com/xebialabs/deployit/plugin/jbossdm/container/Domain.java <==
package com.xebialabs.deployit.plugin.jbossdm.container;

import java.util.List;
import java.util.Map;

import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionContext;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.jbossdm.step.CliInspectionStep;

import static com.google.common.collect.Lists.newArrayList;
import static com.google.common.collect.Maps.newHashMap;

@Metadata(inspectable = true)
public class Domain extends CliBasedContainer {

    @Property(required = false, asContainment = true, description = "Server groups defined in domain")
    private List<ServerGroup> serverGroups = newArrayList();

    @Property(required = false, asContainment = true, description = "Profiles defined in domain")
    private List<Profile> profiles = newArrayList();

    @Inspect
    public void inspect(InspectionContext ctx) {
        Map<String, Object> pyCtx = newHashMap();
        pyCtx.put("container", this);
        CliInspectionStep step = new CliInspectionStep("jboss/dm/container/inspect-domain.py", 0, pyCtx, "Inspect Domain", this);
        ctx.addStep(step);
    }

    @Override
    public String getTargetServerGroup(boolean undeployment) {
        if (undeployment) {
            return "--all-relevant-server-groups";
        }
        return "--all-server-groups";

    }

    public List<ServerGroup> getServerGroups() {
        return serverGroups;
    }

    public void setServerGroups(List<ServerGroup> serverGroups) {
        this.serverGroups = serverGroups;
    }


    public List<Profile> getProfiles() {
        return profiles;
    }

    public void setProfiles(List<Profile> profiles) {
        this.profiles = profiles;
    }

    @Override
    public Mode getMode() {
        return Mode.DOMAIN;
    }
}

==> jbossdm-plugin-3.8.1-sources.jar: com/xebialabs/deployit/plugin/jbossdm/container/Domain.java <==
package com.xebialabs.deployit.plugin.jbossdm.container;

import java.util.Map;
import java.util.Set;

import com.xebialabs.deployit.plugin.api.inspection.Inspect;
import com.xebialabs.deployit.plugin.api.inspection.InspectionContext;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.jbossdm.step.CliInspectionStep;

import static com.google.common.collect.Maps.newHashMap;
import static com.google.common.collect.Sets.newHashSet;

@Metadata(inspectable = true)
public class Domain extends CliBasedContainer {

    @Property(required = false, asContainment = true, description = "Server groups defined in domain")
    private Set<ServerGroup> serverGroups = newHashSet();

    @Property(required = false, asContainment = true, description = "Profiles defined in domain")
    private Set<Profile> profiles = newHashSet();

    @Inspect
    public void inspect(InspectionContext ctx) {
        Map<String, Object> pyCtx = newHashMap();
        pyCtx.put("container", this);
        CliInspectionStep step = new CliInspectionStep("jboss/dm/container/inspect-domain.py", 0, pyCtx, "Inspect Domain", this);
        ctx.addStep(step);
    }

    @Override
    public String getTargetServerGroup(boolean undeployment) {
        if (undeployment) {
            return "--all-relevant-server-groups";
        }
        return "--all-server-groups";

    }

    public Set<ServerGroup> getServerGroups() {
        return serverGroups;
    }

    public void setServerGroups(Set<ServerGroup> serverGroups) {
        this.serverGroups = serverGroups;
    }


    public Set<Profile> getProfiles() {
        return profiles;
    }

    public void setProfiles(Set<Profile> profiles) {
        this.profiles = profiles;
    }

    @Override
    public Mode getMode() {
        return Mode.DOMAIN;
    }
}
